<?php
/*******************************************************************************
*    myMVC - Model-View-Controller for PHP                                     *
*    Copyright (C) 2012 Luca Bertoncello                                       *
*    Hartigstrasse, 12 - 01127 Dresden Deutschland                             *
*    E-Mail: lucabert@lucabert.de, lucabert@lucabert.com                       *
*    http://www.lucabert.de/  http://www.lucabert.com/                         *
*                                                                              *
*    This program is free software; you can redistribute it and/or modify      *
*    it under the terms of the GNU Lesser General Public License as published  *
*    by the Free Software Foundation; version 2.1 of the License.              *
*                                                                              *
*    This program is distributed in the hope that it will be useful,           *
*    but WITHOUT ANY WARRANTY; without even the implied warranty of            *
*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
*    GNU Lesser General Public License for more details.                       *
*                                                                              *
*    You should have received a copy of the GNU Lesser General Public License  *
*    along with this program; if not, write to the Free Software               *
*    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA *
*******************************************************************************/

/**
 * Action-class to manage a login system.
 * User should derive this class to implement an own
 * action for the login page.
 */
abstract class myMVC_BaseLoginAction extends myMVC_BaseAction
{
  private $actions;

  /**
   * Returns the token used to identify the current Action
   * 
   * @return string                 The token
   */
  public static function getActionToken()
  {
    return 'login';
  }

  /**
   * Returns whether the current user is allowed to call the current Action
   * 
   * @return boolean                true if the user may call this Action, false otherwise
   */
  public static function hasUserRightForAction()
  {
    $session = myMVC_HttpSession::getInstance();
    $user = $session->getFromNamespace('LOGIN', 'loggedUser');
    if($user !== NULL && is_subclass_of($user, 'myMVC_BaseLogin'))
      return false;
    return true;
  }

  /**
   * Save the user in the session.
   * User is now logged in.
   * 
   * @param myMVC_BaseLogin $user   The user (it must be a derived class of myMVC_BaseLogin)
   * @throws myMVC_MVCException     On problems
   */
  protected function setLoggedIn($user)
  {
    if($user === NULL || !is_subclass_of($user, 'myMVC_BaseLogin'))
    {
      $msg = myMVC_Logger::doLog(__METHOD__, __LINE__, 'Given user is not a derived class of myMVC_BaseLogin');
      throw new myMVC_MVCException($msg);
    }
// Saving actions, to be used in setNextAction
    $this->actions = myMVC_Controller::getActionsList();
    $this->session->setInNamespace('LOGIN', 'loggedUser', $user);
// The controller has to recreate the rights structure for the new user
    myMVC_Controller::clearActionList();
  }

  /**
   * Sets the next action after a successfully login.
   * If the user tried to call another action, after a successfull login
   * it must be redirected to this action.
   * Otherwise to the default action.
   *
   * @param myMVC_HttpResponse $response    The used response 
   */
  protected function setNextAction($response)
  {
    if($this->session->existsInNamespace('LOGIN', 'nextAction'))
      $response->setNext($this->actions[$this->session->getFromNamespace('LOGIN', 'nextAction')]);
    else
      $response->setNextDefaultAction();
  }
}
?>
